pub struct PythonProvider { /* private fields */ }Implementations
Sourceimpl PythonProvider
impl PythonProvider
Sourcepub async fn preflight(&self) -> Result<(), ProviderError>
pub async fn preflight(&self) -> Result<(), ProviderError>
Starts, negotiates, describes, and health-checks a persistent worker. One-shot providers have no persistent preflight and return immediately.
pub fn new( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, ) -> Self
pub fn new_with_interpreter( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, interpreter: PythonInterpreter, ) -> Self
Sourcepub fn new_persistent(
path: PathBuf,
catalog: ProviderCatalog,
env_prefix: impl Into<String>,
interpreter: PythonInterpreter,
config: PythonSupervisorConfig,
) -> Result<Self, ProviderError>
pub fn new_persistent( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, interpreter: PythonInterpreter, config: PythonSupervisorConfig, ) -> Result<Self, ProviderError>
Builds a provider backed by one lazily-started persistent worker.
pub fn arc_persistent( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, interpreter: PythonInterpreter, config: PythonSupervisorConfig, ) -> Result<Arc<Self>, ProviderError>
Sourcepub fn arc_persistent_in_generation(
path: PathBuf,
catalog: ProviderCatalog,
env_prefix: impl Into<String>,
interpreter: PythonInterpreter,
config: PythonSupervisorConfig,
immutable_generation_digest: String,
) -> Result<Arc<Self>, ProviderError>
pub fn arc_persistent_in_generation( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, interpreter: PythonInterpreter, config: PythonSupervisorConfig, immutable_generation_digest: String, ) -> Result<Arc<Self>, ProviderError>
Builds a persistent provider whose identity and worker budget are bound to the complete immutable source-tree generation.
pub fn arc( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, ) -> Arc<Self> ⓘ
pub fn arc_with_interpreter( path: PathBuf, catalog: ProviderCatalog, env_prefix: impl Into<String>, interpreter: PythonInterpreter, ) -> Arc<Self> ⓘ